@@ -39,7 +39,10 @@ class Mod:
         self.tabix = pysam.Tabixfile(self.fileName)
         self.tabix_chroms = set([c.decode('utf-8')
                                  for c in self.tabix.contigs])
+        #self.tabix_chroms = set([c for c in self.tabix.contigs])
         self.fetch = self.tabix.fetch
+
+        #print(self.tabix_chroms)
         #for line in self.tabix.fetch('chr1'):
         #    print(line)
 
@@ -218,7 +221,7 @@ class Mod:
 
             #print(self.tabix_chroms)
             if chrom in self.tabix_chroms:
-                for line in self.tabix.fetch(reference=chrom):
+                for line in self.tabix.fetch(reference=str(chrom)):
                     try:
                         n += 1
                         cols = line.split('\t')
